Home
last modified time | relevance | path

Searched refs:weak (Results 1 – 25 of 303) sorted by relevance

12345678910>>...13

/freebsd-13.1/lib/libc/gen/
H A Ddlfcn.c66 #pragma weak _rtld_error
72 #pragma weak dladdr
81 #pragma weak dlclose
90 #pragma weak dlerror
98 #pragma weak dllockinit
113 #pragma weak dlopen
122 #pragma weak dlsym
131 #pragma weak dlfunc
140 #pragma weak dlvsym
150 #pragma weak dlinfo
[all …]
H A D_spinlock_stub.c52 #pragma weak _spinlock
62 #pragma weak _spinunlock
/freebsd-13.1/crypto/openssl/include/openssl/
H A Dsafestack.h178 # pragma weak OPENSSL_sk_num
179 # pragma weak OPENSSL_sk_value
180 # pragma weak OPENSSL_sk_new
184 # pragma weak OPENSSL_sk_free
185 # pragma weak OPENSSL_sk_zero
188 # pragma weak OPENSSL_sk_push
190 # pragma weak OPENSSL_sk_pop
194 # pragma weak OPENSSL_sk_set
195 # pragma weak OPENSSL_sk_find
197 # pragma weak OPENSSL_sk_sort
[all …]
H A Dlhash.h221 # pragma weak OPENSSL_LH_new
222 # pragma weak OPENSSL_LH_free
223 # pragma weak OPENSSL_LH_insert
224 # pragma weak OPENSSL_LH_delete
225 # pragma weak OPENSSL_LH_retrieve
226 # pragma weak OPENSSL_LH_error
227 # pragma weak OPENSSL_LH_num_items
230 # pragma weak OPENSSL_LH_stats_bio
231 # pragma weak OPENSSL_LH_get_down_load
233 # pragma weak OPENSSL_LH_doall
[all …]
/freebsd-13.1/contrib/libcxxrt/
H A Dmemory.cc61 __attribute__((weak))
66 __attribute__((weak))
83 __attribute__((weak))
108 __attribute__((weak))
121 __attribute__((weak))
128 __attribute__((weak))
135 __attribute__((weak))
148 __attribute__((weak))
158 __attribute__((weak))
165 __attribute__((weak))
/freebsd-13.1/contrib/llvm-project/clang/lib/Headers/
H A D__clang_hip_runtime_wrapper.h35 __attribute__((weak))
41 __attribute__((weak))
80 __attribute__((weak)) inline __device__ void *malloc(__hip_size_t __size) { in malloc()
83 __attribute__((weak)) inline __device__ void *free(void *__ptr) { in free()
87 __attribute__((weak)) inline __device__ void *malloc(__hip_size_t __size) {
91 __attribute__((weak)) inline __device__ void *free(void *__ptr) {
/freebsd-13.1/lib/libc/mips/
H A DSYS.h106 .weak _C_LABEL(x); \
108 .weak _C_LABEL(__CONCAT(_,x)); \
119 .weak _C_LABEL(x); \
121 .weak _C_LABEL(__CONCAT(_,x)); \
137 .weak _C_LABEL(__CONCAT(_,x)); \
145 .weak _C_LABEL(__CONCAT(_,x)); \
/freebsd-13.1/sys/dev/uart/
H A Duart.h104 extern struct uart_class uart_ns8250_class __attribute__((weak));
105 extern struct uart_class uart_quicc_class __attribute__((weak));
106 extern struct uart_class uart_s3c2410_class __attribute__((weak));
107 extern struct uart_class uart_sbbc_class __attribute__((weak));
108 extern struct uart_class uart_z8530_class __attribute__((weak));
/freebsd-13.1/contrib/llvm-project/libunwind/src/
H A DRWMutex.hpp77 extern "C" int __attribute__((weak))
80 extern "C" int __attribute__((weak))
82 extern "C" int __attribute__((weak))
84 extern "C" int __attribute__((weak))
/freebsd-13.1/contrib/llvm-project/compiler-rt/lib/hwasan/
H A Dhwasan_setjmp.S90 .weak sigsetjmp
93 .weak setjmp
96 .weak __sigsetjmp
100 .weak _setjmp
/freebsd-13.1/contrib/llvm-project/compiler-rt/lib/xray/
H A Dxray_init.cpp25 extern const XRaySledEntry __start_xray_instr_map[] __attribute__((weak));
26 extern const XRaySledEntry __stop_xray_instr_map[] __attribute__((weak));
27 extern const XRayFunctionSledIndex __start_xray_fn_idx[] __attribute__((weak));
28 extern const XRayFunctionSledIndex __stop_xray_fn_idx[] __attribute__((weak));
/freebsd-13.1/sys/amd64/linux/
H A Dlinux_locore.asm39 .weak clock_gettime
46 .weak time
53 .weak gettimeofday
59 .weak getcpu
/freebsd-13.1/contrib/file/magic/Magdir/
H A Dweak3 # weak: file(1) magic for very weak magic entries, disabled by default
5 # These entries are so weak that they might interfere identification of
/freebsd-13.1/contrib/llvm-project/openmp/runtime/src/thirdparty/ittnotify/
H A Dittnotify_config.h358 void *dlopen(const char *, int) __attribute__((weak));
359 void *dlsym(void *, const char *) __attribute__((weak));
360 int dlclose(void *) __attribute__((weak));
364 __attribute__((weak));
365 int pthread_mutex_lock(pthread_mutex_t *) __attribute__((weak));
366 int pthread_mutex_unlock(pthread_mutex_t *) __attribute__((weak));
367 int pthread_mutex_destroy(pthread_mutex_t *) __attribute__((weak));
368 int pthread_mutexattr_init(pthread_mutexattr_t *) __attribute__((weak));
369 int pthread_mutexattr_settype(pthread_mutexattr_t *, int) __attribute__((weak));
370 int pthread_mutexattr_destroy(pthread_mutexattr_t *) __attribute__((weak));
[all …]
/freebsd-13.1/contrib/llvm-project/compiler-rt/lib/scudo/standalone/include/scudo/
H A Dinterface.h17 __attribute__((weak)) const char *__scudo_default_options();
21 __attribute__((weak)) void __scudo_allocate_hook(void *ptr, size_t size);
22 __attribute__((weak)) void __scudo_deallocate_hook(void *ptr);
/freebsd-13.1/lib/libc/arm/
H A DSYS.h55 .weak _C_LABEL(x); \
57 .weak _C_LABEL(__CONCAT(_,x)); \
71 .weak _C_LABEL(__CONCAT(_,x)); \
/freebsd-13.1/sys/contrib/openzfs/module/lua/setjmp/
H A Dsetjmp_ppc.S59 .weak name; \
68 .weak name; \
69 .weak GLUE(.,name); \
86 .weak name; \
/freebsd-13.1/lib/libc/sys/
H A Dtrivial-vdso_tc.c34 #pragma weak __vdso_gettc
42 #pragma weak __vdso_gettimekeep
/freebsd-13.1/stand/libsa/zfs/
H A Ddevicename_stubs.c33 __attribute__((weak))
40 __attribute__((weak))
/freebsd-13.1/contrib/llvm-project/compiler-rt/lib/builtins/arm/
H A Daeabi_div0.c31 AEABI_RTABI int __attribute__((weak)) __attribute__((visibility("hidden")))
36 AEABI_RTABI long long __attribute__((weak))
/freebsd-13.1/contrib/llvm-project/compiler-rt/lib/crt/
H A Dcrtbegin.c17 extern void __register_frame_info(const void *, void *) __attribute__((weak));
18 extern void *__deregister_frame_info(const void *) __attribute__((weak));
29 extern void __cxa_finalize(void *) __attribute__((weak));
/freebsd-13.1/sys/libkern/
H A Dexplicit_bzero.c16 __attribute__((weak)) void __explicit_bzero_hook(void *, size_t);
18 __attribute__((weak)) void
/freebsd-13.1/lib/libc/riscv/sys/
H A D__vdso_gettc.c40 #pragma weak __vdso_gettc
51 #pragma weak __vdso_gettimekeep
/freebsd-13.1/lib/libc/powerpc/sys/
H A D__vdso_gettc.c46 #pragma weak __vdso_gettc
62 #pragma weak __vdso_gettimekeep
/freebsd-13.1/lib/libc/powerpc64/sys/
H A D__vdso_gettc.c45 #pragma weak __vdso_gettc
59 #pragma weak __vdso_gettimekeep

12345678910>>...13